@@ -131,10 +131,7 @@ stack::segment::segment(call *cr, int cid, int did, int tid) : OrderedObject()
     sid.reg = NULL;
     sid.closed = false;
 
-    static unsigned short sequence = 0;
-    Mutex::protect(&sequence);
-    process::uuid(sid.uuid, sizeof(sid.uuid), ++sequence, cid);
-    Mutex::release(&sequence);
+    secure::uuid(sid.uuid);
 }
 
 void *stack::segment::operator new(size_t size)
@@ -277,7 +274,7 @@ void stack::disableDumping(void)
 void stack::clearDumping(void)
 {
     ::remove(DEFAULT_VARPATH "/log/sipdump.log");
-    ::remove(_STR(process::path("controls") + "/sipdump.log"));
+    ::remove(_STR(control::path("controls") + "/sipdump.log"));
 }
 
 void stack::enableDumping(void)
@@ -297,7 +294,7 @@ void stack::siplog(osip_message_t *msg)
 
     osip_message_to_str(msg, &text, &tlen);
     if(text) {
-        fsys::create(log, process::get("siplogs"), fsys::ACCESS_APPEND, 0660);
+        fsys::create(log, control::env("siplogs"), fsys::ACCESS_APPEND, 0660);
         if(is(log)) {
             Mutex::protect(&stack::sip.dumping);
             fsys::write(log, text, tlen);
@@ -699,7 +696,7 @@ void stack::start(service *cfg)
         mapped_calls, threading, priority);
     eXosip_init();
 
-    mapped_array<MappedCall>::create(CALL_MAP, mapped_calls);
+    mapped_array<MappedCall>::create(control::env("callmap"), mapped_calls);
     if(!sip)
         shell::log(shell::FAIL, "calls could not be mapped");
     initialize();
@@ -771,7 +768,7 @@ void stack::stop(service *cfg)
     thread::shutdown();
     Thread::yield();
     MappedMemory::release();
-    MappedMemory::remove(CALL_MAP);
+    MappedMemory::remove(control::env("callmap"));
 }
 
 bool stack::check(void)
@@ -1255,7 +1252,7 @@ int stack::inviteRemote(stack::session *s, const char *uri_target, const char *d
         char *req = NULL;
         osip_uri_to_str(invite->req_uri, &req);
         snprintf(authbuf, 1024, "%s:%s", invite->sip_method, req);
-        process::uuid(nounce, sizeof(nounce), "auth");
+        Random::uuid(nounce);
 
         digest_t auth = "md5";
         auth.puts(nounce);
